@@ -28,13 +28,18 @@ class FakeNetwork:
 
 
 class RecordingLogger:
-    def __init__(self, _network: object, _runtime: object, **_: Any) -> None:
+    def __init__(self, _sdk_key: str, _network: object, _runtime: object, **_: Any) -> None:
         self.events: list[WolvesEvent] = []
         self.stopped = False
 
     def enqueue(self, event: WolvesEvent) -> None:
         self.events.append(event)
 
+    def flush(self) -> WolvesFuture[None]:
+        fut: concurrent.futures.Future[None] = concurrent.futures.Future()
+        fut.set_result(None)
+        return WolvesFuture(fut)
+
     def stop(self) -> WolvesFuture[None]:
         self.stopped = True
         fut: concurrent.futures.Future[None] = concurrent.futures.Future()
