@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import asyncio
-from typing import Any, Literal, Mapping
+from typing import Any, Mapping
 
 import httpx
 
@@ -15,9 +15,9 @@ API_LOCAL = "http://localhost:8000/api"
 API_DEV = "https://wolves-nova-dev.azurewebsites.net/api"
 API_PROD = "https://wolves-nova.azurewebsites.net/api"
 
-ApiEnvironment = Literal["local", "dev", "prod"]
+ApiEnvironment = str
 
-API_ENDPOINTS: dict[ApiEnvironment, str] = {
+API_ENDPOINTS: dict[str, str] = {
     "local": API_LOCAL,
     "dev": API_DEV,
     "prod": API_PROD,
